"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchMock = exports.koFetchMock = exports.okFetchMock = void 0;
exports.okFetchMock = jest.fn(fetchMock({}));
exports.koFetchMock = jest.fn(() => Promise.resolve({
    ok: false,
    json: () => Promise.resolve({}),
    status: 500,
    statusText: 'Unexpected error'
}));
/**
 * The `fetchMock()` method mocks a `fetch` API call.
 *
 * @param response - The expected response resolved by calling `fetch()`.
 * @returns A Promise object.
 *
 * @internal
 */
function fetchMock(response) {
    return (_url, { signal }) => {
        return new Promise((resolve, reject) => {
            setTimeout(() => {
                if (signal === null || signal === void 0 ? void 0 : signal.aborted) {
                    reject(new DOMException('Aborted', 'AbortError'));
                }
                else {
                    resolve({
                        ok: true,
                        status: 200,
                        json: () => Promise.resolve(response),
                        text: () => Promise.resolve(JSON.stringify(response))
                    });
                }
            });
        });
    };
}
exports.fetchMock = fetchMock;
//# sourceMappingURL=fetch.mock.js.map