"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildUrl = exports.toJson = void 0;
const x_utils_1 = require("@empathyco/x-utils");
const request_error_1 = require("./errors/request-error");
/**
 * Formats a response object to JSON.
 *
 * @remarks If the `response.ok` is falsy, a `RequestError` object is thrown.
 *
 * @param response - The response to convert to JSON format.
 * @returns - The resultant promise of formatting the response to JSON.
 *
 * @public
 */
function toJson(response) {
    if (response.ok) {
        return response.text().then(text => (text ? JSON.parse(text) : {}));
    }
    else {
        throw new request_error_1.RequestError('Request failed', response);
    }
}
exports.toJson = toJson;
/**
 * Builds a URL object based on the passed endpoint and the request parameters.
 *
 * @param endpoint - The endpoint.
 * @param params - The request parameters.
 *
 * @returns The `href` property of the newly built `URL` object.
 *
 * @public
 */
function buildUrl(endpoint, params = {}) {
    const url = new URL(endpoint);
    (0, x_utils_1.forEach)(params, (key, value) => (Array.isArray(value) ? value : [value]).forEach(arrayItemValue => url.searchParams.append(key, String(arrayItemValue))));
    return url.href;
}
exports.buildUrl = buildUrl;
//# sourceMappingURL=utils.js.map